bruker2nifti.parsers package
============================

Submodules
----------

bruker2nifti.parsers.bruker2nii module
--------------------------------------

.. automodule:: bruker2nifti.parsers.bruker2nii
    :members:
    :undoc-members:
    :show-inheritance:

bruker2nifti.parsers.bruker2nii_scan module
-------------------------------------------

.. automodule:: bruker2nifti.parsers.bruker2nii_scan
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: bruker2nifti.parsers
    :members:
    :undoc-members:
    :show-inheritance:
